/* Simple (?) install program for open-ssh.                                  */
/*                                                                           */
/* This uses rexxlib.dll as per license.  It may not be used except in       */
/* accordance with the Quercus software license.                             */
/*                                                                           */
/* You may freely edit (hopefully to improve) this program and redistribute. */
/* Please give credit where credit is due.  And of course the author of the  */
/* program takes no responsibility for anything.                             */
/*                                                                           */
/* Doug Rickman.  MSFC/NASA  Oct 30, 2002                                    */
/*                                                                           */
/* Algorithm:                                                                */
/* 1. Telling the user the general nature of what is to be done.             */
/* 2  Check and edit the config.sys.                                         */
/*    A. Check that /mptn/bin and /mptn/dll are in paths.                    */
/*    B. If necessary ETC, HOME and USER are set.                            */
/*    C. /ETC/SSH and $HOME/.ssh are created if necessary.                   */
/*    D. Returns to the main program the USER, and the ETC, BIN, DLL, and    */
/*       HOME directories.                                                   */
/* 2. Files are then copied into their appropriate places.                   */
/* 3. A text file is created which contains the suggested commands the user  */
/* will have to type after INSTALL.CMD is done and perhaps the system is     */
/* rebooted.                                                                 */
/*                                                                           */
/* Files may or may not need to be copied to many different locations.  This */
/* is the cause of much of the program's complication. I also wanted         */
/* the ability for future versions of this program to install only ssh or    */
/* only sshd.                                                                */
/*                                                                           */
/* Therefore, I have subdivided the files to be installed based on type of   */
/* file (exe, config) and whether it is required by ssh, sshd or both.  Each */
/* group of files is placed in a subroutine at the end of the program.       */
/* Thus to add or delete files from the package and the install process do   */
/* the following.                                                            */
/* 1. Add/remove the file from the appropriate subroutine.  Be sure to change*/
/*    the value of File.0 for the routine.                                   */
/* 2. All files are copied using the subroutine CopyFiles().  It operates on */
/*    type of files (i.e. files from a single subroutine) at a time.  You may*/
/*    or may not need to alter CopyFiles().                                  */
/* 3. To add or change instructions in the script file built for the user    */
/*    you will need to edit CreateCommandScript).                            */
/*                                                                           */

say ' '
say 'This program will install open-ssh client and server files on your boot'
say 'drive.  If the corresponding files already exist they will be replaced.'
say '** BACKUP ** your CONFIG.SYS and any existing open-ssh files before '
say 'continuing. See OPEN-SSH_4OS2.INF for a list of files and directories involved.'
say ' '
say 'Installation steps done by this program.'
say '1. The CONFIG.SYS is checked for \MPTN\BIN and \MPTN\DLL.'
say '2. If the line "SET ETC =  " is not in your CONFIG.SYS it will be added.'
say '3. If the line "SET USER = " is not in your CONFIG.SYS it will be added.'
say '4. If the line "SET HOME = " is not in your CONFIG.SYS it will be added.'
say '5. Create the HOME directory if necessary.'
say '6. If the program sh.exe is not in your PATH it will be added.'
say '7. Copy .exe and .dll files from the distribution to their proper location.'
say '8. Copy configuration and example files from the distribution to their '
say '   proper location, asking permission before overwriting.'
say '9. Prepare a file with the commands you need to run manually.'
do screenlines = 1 to 22-16
   say ' '
   end screenlines
say 'Please hit enter to continue.  CNTL C will abort processing.'
pull trash

/* Get the current directory. */
CDir = directory()

if rxfuncquery('rexxlibregister') then do         /* this will start rexxlib */
   call rxfuncadd 'rexxlibregister', CDir'\rexxlib.dll', 'rexxlibregister'  
   call rexxlibregister
   end
if rxfuncquery('sysloadfuncs') then do           /* this will start rexxutil */
   CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs' 
   CALL SysLoadFuncs
   end

/* Files to install are grouped */

Reboot = 0  /* This is set to 1 if the system will need a reboot. */

/* Get the boot drive. */
BootDrive = dosbootdrive() ||':'


/* See if LIBPATH, PATH, ETC, USER and HOME are set in config.sys as needed. */
rc = ConfigSysTool(BootDrive)
if rc \= 1 then do
   return -1
   end

rc = CopyFiles(SHFlag,home,user,DLLDir,EXEDir,ETCDir)
if rc \= 1 then do
   parse var rc . rc FileName
   say 'Copying of file "'CDir||FileName'"'
   say 'failed with the REXXLIB doscopy() error code 'rc'.'
   say 'Be sure: '
   say '1. the target files are not set to read only, system or hidden;'
   say '2. the target files are not currently opened by an editor or other program;'
   say '3. ssh and sshd are not running;'
   say '4. there is room on the target disk;'
   say '5. the source file(s) exist.'
   return -1
   end

/* Create a file with the needed commands after reboot. */
Script = CDir'\_commands_for_you_to_do.txt'
rc = CreateCommandScript(home,user,ETCDir,Script,USERFlag,HOMEFlag)
if rc \= 1 then do
   return -1
   end

/* Give user final directions. */
if UFlag =1 | SFlag = 1 then do 
   say 'The file, "'CDir'\_commands_for_you_to_do.txt",'
   say 'has been created containing the commands needed to make:'
   if UFlag = 1 then    
      say '    a private and public key pair for 'user
   if SFlag = 1 then 
      say '    keys for the sshd server.'
   end
if Reboot = 1 then do
   say 'But in this case your CONFIG.SYS has been edited.  Therefore,'
   say '*** YOU WILL HAVE TO REBOOT BEFORE RUNNING THE COMMANDS! ***'
   say ''
   end
if UFlag\=1 & SFlag\=1 & Reboot\=1 then do
   say 'As far as I can tell you are ready to run ssh and sshd again.'
   end

return -1


/*    ------------------------------------------------------------------     */
/* Read the config.sys.                                                      */
/* Check that /MPTN/DLL and /MPTN/BIN are in the PATH and LIBPATH.           */
/* Check that "ETC" is set.  If not then set it.                             */
/* Check for "HOME" and "USER".  Set them if necessary.                      */
ConfigSysTool:
procedure expose reboot home user DLLDir EXEDir ETCDir USERFlag HOMEFlag 
BootDrive = arg(1)

in = BootDrive||'\Config.sys'

in=stream(in,'c','query exists')
if in = '' then do
   say 'The input file: 'in' is not a valid file.'   
   return 0
   end
/* We now have the full name, including drive and path in the variable "in". */

rc=stream(in,'c','open')
if rc \= 'READY:' then do
   say 'The input file: 'in' could not be opened.'
   say 'Is it locked by another program?  Do you have write permission?'
   return 0
   end 
rc=stream(in,'c','close')

do i = 1
   data.i = linein(in)
   if lines(in) = 0 then
      leave i
   end i
data.0 = i

/* Check LIBPATH.  Assume \MPTN\BIN is there. */
LibPathFlag = 1
do i = 1 to data.0
   v1 = translate(data.i,' ','=')
   v1 = space(strip(translate(v1)))
   if left(v1,7)='LIBPATH' then do
      parse var v1 . Path
      do j = 1 while Path \= ''
         parse var Path v2 ';' Path
         if v2 = BootDrive||'\MPTN\DLL' then do
            DLLDir = v2
            leave i
            end
         end j
      LibPathFlag = 0
      end
   end
if LibPathFlag = 0 then do
   say BootDrive||'\MPTN\DLL is not in your path.  This must be fixed before continuing.'
   end


/* Check PATH.  Assume \MPTN\BIN is there. */
PathFlag = 1
do i = 1 to data.0
   v1 = translate(data.i,' ','=')
   v1 = space(strip(translate(v1)))
   if left(v1,8)='SET PATH' then do
      parse var v1 . . Path
      do j = 1 while Path \= ''
         parse var Path v2 ';' Path
         if v2 = BootDrive||'\MPTN\BIN' then do
            EXEDir = v2
            leave i
            end
         end j
      PathFlag = 0   
      end
   end i
if PathFlag = 0 then do
   say BootDrive||'\MPTN\BIN is not in your path.  This must be fixed before continuing.'
   end

if LibPathFlag*PathFlag = 0 then
   return -1

say 'LIBPATH & PATH are OK.'

/* Check for SET ETC */
ETCFlag = 0
do i = 1 to data.0
   v1 = translate(data.i,' ','=')
   v1 = space(strip(translate(v1)))
   if left(v1,8)='SET ETC ' then do  /* SET ETC=C:\MPTN\ETC */
      parse var data.i . '=' ETCDir .
      ETCFlag = 1
      leave i
      end
   end
if ETCFlag = 0 then do
   ETCDir = BootDrive||'\MPTN\ETC'
   v  = 'SET ETC='ETCDir
   rc = WriteCONFIGsys(in,v)
   if rc \= 1 then 
      return -2
   ETCFlag = 1
   end
rc = dosmkdir(ETCDir'\ssh') /* Make sure the ssh directory exists. */

say '"SET ETC  = " is OK'

/* Check for SET USER */
USERFlag = 0
do i = 1 to data.0
   v1 = translate(data.i,' ','=')
   v1 = space(strip(translate(v1)))
   if left(v1,9)='SET USER ' then do  /* set USER=doug */
      parse var data.i . '=' user .
      USERFlag = 1
      leave i
      end
   end
if USERFlag = 0 then do
   rc = DefineUSER(in)
   if rc \= 1 then 
      return -4
   USERFlag = 2
   end

say '"SET USER = " is OK'

/* Check for SET HOME */
HOMEFlag = 0
do i = 1 to data.0
   v1 = translate(data.i,' ','=')
   v1 = space(strip(translate(v1)))
   if left(v1,9)='SET HOME ' then do  /* set HOME=d:\home\doug */
      parse var data.i . '=' HOME .
      HOMEFlag = 1
      leave i
      end
   end
if HOMEFlag = 0 then do
   rc = DefineHOME(in,user)
   if rc \= 1 then 
      return -3
   HOMEFlag = 2
   end

/* Make sure directories exist. */
rc = dosmakedir(HOME)
if rc \= 1 then do
   say 'Unable to create the home directory, "'HOME'".  Something is wrong!'
   return -1
   end
rc = dosmakedir(HOME'\.ssh')
if rc \= 1 then do
   say 'Unable to create the home directory, "'HOME'".  Something is wrong!'
   return -1
   end


say '"SET HOME = " is OK'

drop data.

return 1
/*    ------------------------------------------------------------------     */


/*    ------------------------------------------------------------------     */
CopyFiles:
procedure

SHFlag = arg(1)
home   = arg(2)
user   = arg(3)
DLLDir = arg(4)
EXEDir = arg(5)
ETCDir = arg(6)

/* Start copying EXE files. */
Mode = 'R'  /* For testing change this to 'N' and no files will be replaced. */
rc = SSHexeFiles()
do i = 1 to File.0
   rc = doscopy('.'File.i,EXEDir||File.i,Mode)
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

rc = SSHDexeFiles()
do i = 1 to File.0
   rc = doscopy('.'File.i,EXEDir||File.i,Mode)
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

/* Is there an existing sh.exe in the path? */
SHFlag = 1      /* Yes */
filespec = SysSearchPath('PATH','SH.EXE') 
if filespec = '' then do
   SHFlag = 0   /* No  */
   end

rc = SSH_SSHDexeFiles()
do i = 1 to File.0
   if SHFlag = 1 & File.i = '\sh.exe' then
      iterate i /* Do not replace an existing sh.exe. */
   rc = doscopy('.'File.i,EXEDir||File.i,Mode)
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

/* Start copying DLL files. */
rc = SSHDdllFiles()
do i = 1 to File.0
   rc = doscopy('.'File.i,DLLDir||File.i,Mode)
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

say '.EXE and .DLL files have been copied.'
say ' '
say 'Do you wish to overwrite existing configuration or rc files used by open-ssh?'
say 'yes/no  A blank return will not replace any existing files.'  

do screenlines = 1 to 23-8 ; say ' ' ; end screenlines
Mode = inkey()
if   Mode \='0D'x then Mode = left(translate(Mode),1)
else Mode  = 'N'
if   Mode  = 'Y'  then Mode = 'R'

/* Start copying config files. */
rc = SSHconfigFiles()

do i = 1 to File.0
   v=lastpos('\',File.i) + 1
   parse var File.i . =(v) FileName
   if File.i = '\rc' then
      rc = doscopy('.'File.i,Home||'\.ssh'File.i,Mode)   
   else   
      rc = doscopy('.'File.i,ETCDir||'\ssh\'FileName,Mode)   
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

rc = SSHDconfigFiles()

do i = 1 to File.0
   parse var File.i . 'ETC\' File .
   rc = doscopy('.'File.i,ETCDir||'\'File,Mode)   
   if rc=0 | (rc=5 & Mode='N') then
      iterate i
   return -1 rc File.i
   end i

/*                                                                           */
/* Ask whether or not to install each optional file.                         */
/*                                                                           */
say 'Do you wish to have a banner file installed?  The template looks like this:'
say ' '
say '**************************************************************************'
say 'WARNING!  This is a U.S. Government computer.  This system is for the use'
say 'of authorized users only.  By accessing and using the computer system you'
say 'are consenting to system monitoring, including the monitoring of'
say 'keystrokes.  Unauthorized use of, or access to, this computer system may'
say 'subject you to disciplinary action and criminal prosecution.'
say '**************************************************************************'
say ''
say '               Abandon HOPE! All ye who enter here!'
say ''
say '     **************************************************************'
say ''
say 'yes/no  A blank return will NOT install the template banner file.'

do screenlines = 1 to 23-15 ; say ' ' ; end screenlines
BMode = inkey()
if   BMode \='0D'x then BMode = left(translate(BMode),1)
else BMode  = 'N'
if   BMode  = 'Y'  then BMode = 'R'


say 'Do you wish to use the sshd_config file that Doug uses?  It is more'
say 'restrictive than the default sshd_config and it uses a banner file.'
say ' '
say ' '
say 'yes/no  A blank return will NOT install Doug''s sshd_config file'

do screenlines = 1 to 23-5 ; say ' ' ; end screenlines
CMode = inkey()
if   CMode \='0D'x then CMode = left(translate(CMode),1)
else CMode  = 'N'
if   CMode  = 'Y'  then CMode = 'R'


say 'Do you want your existing syslog.cnf file to be replaced? Do not do this'
say 'if you have already customized your existing copy.'
say ' '
say 'yes/no  A blank return will NOT replace the existing file.'

do screenlines = 1 to 23-4 ; say ' ' ; end screenlines
SMode = inkey()
if   SMode \='0D'x then SMode = left(translate(SMode),1)
else SMode  = 'N'
if   SMode  = 'Y'  then SMode = 'R'

/*                                                                           */
/* Based on responses to questions, copy files.                              */
/*                                                                           */
rc = OptionalConfigFiles()

do i = 1 to File.0
   select
      when File.i = '\ETC\ssh\SSH_BANNER.TXT' then do
         rc = doscopy('.'File.i,ETCDir||'\ssh\SSH_BANNER.TXT',BMode)   
         if rc=0 | (rc=5 & BMode='N') then
            iterate i
         return -1 rc File.i
         end
      when File.i = '\etc\ssh\sshd_config.doug' then do
         rc = doscopy('.'File.i,ETCDir||'\ssh\sshd_config',CMode)   
         if rc=0 | (rc=5 & CMode='N') then
            iterate i
         return -1 rc File.i
         end
      when File.i = '\ETC\syslog.cnf' then do
         rc = doscopy('.'File.i,ETCDir||'\syslog.cnf',SMode)   
         if rc=0 | (rc=5 & SMode='N') then
            iterate i
         return -1 rc File.i
         end
      otherwise do
         say 'There is an unexpected file, "'File.i'"'
         say 'in the OptionalConfigFiles() list.'
         end
      end /* select */
   end i

/* rc = ExampleFiles() */

return 1
/*    ------------------------------------------------------------------     */

/*    ------------------------------------------------------------------     */
CreateCommandScript:
procedure expose USERFlag HOMEFlag SFlag UFlag
home     = arg(1)
user     = arg(2)
ETCDir   = arg(3)
out      = arg(4)
USERFlag = arg(5)
HOMEFlag = arg(6)

SFlag = 0
UFlag = 0

rc = dosdel(out)

/* Does the server have existing keys? */
rc1 = dosisfile(ETCDir'\ssh\ssh_host_dsa_key')
rc2 = dosisfile(ETCDir'\ssh\ssh_host_dsa_key.pub')
if rc1\=1 | rc2\=1 then do
   rc = stream(out,'c','open')
   rc = lineout(out,' ')
   rc = lineout(out,'Open a shell and enter the following command to create dsa keys.')
   rc = lineout(out,'ssh-keygen -b 2048 -t dsa  -f /etc/ssh_host_dsa_key -N "" ')
   rc = stream(out,'c','close')
   SFlag = 1
   end

rc1 = dosisfile(ETCDir'\ssh\ssh_host_rsa_key')
rc2 = dosisfile(ETCDir'\ssh\ssh_host_rsa_key.pub')
if rc1\=1 | rc2\=1 then do
   rc = stream(out,'c','open')
   rc = lineout(out,' ')
   rc = lineout(out,'Open a shell and enter the following command to create rsa2 keys.')
   rc = lineout(out,'ssh-keygen -b 2048 -t rsa  -f /etc/ssh_host_rsa_key -N "" ')
   rc = stream(out,'c','close')
   SFlag = 1
   end

rc1 = dosisfile(ETCDir'\ssh\ssh_host_key')
rc2 = dosisfile(ETCDir'\ssh\ssh_host_key.pub')
if rc1\=1 | rc2\=1 then do
   rc = stream(out,'c','open')
   rc = lineout(out,' ')
   rc = lineout(out,'Open a shell and enter the following command to create rsa keys.')
   rc = lineout(out,'ssh-keygen -b 2048 -t rsa1 -f /etc/ssh_host_key   -N "" ')
   rc = stream(out,'c','close')
   SFlag = 1
   end

/* User setup and key generation. */
rc1 = dosisfile(Home'\.ssh\authorized_keys')
rc2 = dosisfile(ETCDir'\passwd')
if rc1=1 & rc2=1 & USERFlag=1 & HOMEFlag=1 then 
   nop
else do
   rc = stream(out,'c','open')
   rc = lineout(out,' ')
   rc = lineout(out,'Open a shell and do the following command(s) as necessary.')
   rc = lineout(out,' ')
   if rc2 \= 1 then do
      rc = lineout(out,'You must have a passwd file.  Do the following')
      rc = lineout(out,'user -a' user)
      rc = lineout(out,'user -c' user)
      rc = lineout(out,'Enter your password as directed.')
      rc = lineout(out,' ')
      end
   if rc2=1 & USERFlag=2 then do
      rc = lineout(out,'You must have a passwd file.  Do the following')
      rc = lineout(out,'user -a' user)
      rc = lineout(out,'Enter your password as directed.')
      rc = lineout(out,' ')
      end

   rc = lineout(out,'To use dsa keys you must have an authorized_keys file.')
   rc = lineout(out,'Open a shell and do one or the other of the following two lines.')
   rc = lineout(out,'and then do the copy operation.')
   rc = lineout(out,'ssh-keygen.exe -b 2048 -t dsa         (Passphrase will be required  ) or')
   rc = lineout(out,'ssh-keygen.exe -b 2048 -t dsa -N ""   (Passphrase will not be required)')
   rc = lineout(out,' ')
   rc = lineout(out,'copy 'Home'\.ssh\id_dsa.pub 'Home'\.ssh\authorized_keys')
   rc = stream(out,'c','close')
   UFlag = 1
   end

return 1
/*    ------------------------------------------------------------------     */

/*    ------------------------------------------------------------------     */
DefineHOME:
procedure expose reboot home
in   = arg(1)
user = arg(2)

say 'A "HOME" directory must be defined.  Given a drive letter a directory'
say 'named Drive:\HOME\'user' will be created if it does not already exist.'
say 'Also the the line "SET HOME=..." will be added to the CONFIG.SYS.'
say ''
say 'Please enter the letter of the drive for this directory.  It can not be a'
say 'FAT formatted drive.  A blank return will abort this process.'
do screenlines = 1 to 23-5
   say ' '
   end screenlines

pull Drive

if Drive = '' then do
   say 'Aborting. If your CONFIG.SYS was already edited restore it from your'
   say 'backup.'
   return 0
   end

drive = left(strip(drive),1)
HOME = Drive':\HOME\'user
v = 'SET HOME = 'HOME
rc = WriteCONFIGsys(in,v)
if rc \= 1 then 
   return -2

return 1
/*    ------------------------------------------------------------------     */


/*    ------------------------------------------------------------------     */
DefineUSER:
procedure expose reboot user 
in = arg(1)

say 'A "USER" must be defined.  This will be your "name" when running ssh.'
say 'I suggest something simple, without blanks or spaces. Many people use'
say 'their first initial and their last name.'
say ''
say 'Please enter the user name.  A blank return will abort this process.'
do screenlines = 1 to 23-5
   say ' '
   end screenlines

pull user
if user = '' then do
   say 'Aborting. If your CONFIG.SYS was already edited restore it from your'
   say 'backup.'
   return 0
   end

user = strip(user)
v = 'SET USER = 'user
rc = WriteCONFIGsys(in,v)
if rc \= 1 then 
   return -2

return 1
/*    ------------------------------------------------------------------     */


/*    ------------------------------------------------------------------     */
WriteCONFIGsys:
procedure expose reboot

in     = arg(1)
string = arg(2)

rc1 = 0
rc2 = 0
rc3 = 0

if reboot = 0 then do
   rc1 = lineout(in,' ')
   rc2 = lineout(in,'REM Needed by open-ssh')
   end
rc3 = lineout(in,string)
rc = stream(in,'c','close')
if rc1+rc2+rc3 \= 0 then do
   say ' '
   say '                ***************************************               '
   say '                 Error while writing to the CONFIG.SYS.               '
   say '        Something is very wrong.  I was unable to properly write.     '
   say '   I recommend restoring your config.sys from a backup.  You did make '
   say '       a backup?  Of course you did what you were told to do.         '
   say '                ***************************************               '
   say ' '
   return -1
   end

Reboot = 1
return 1
/*    ------------------------------------------------------------------     */


/* File definitions follow.  This way a more advanced installer can be       */
/* selective on what is installed.  Also someone else can easily edit this   */
/* information to add, delete or otherwise control what files are used.      */
/*                                                                           */
/* The definition for a file gives its location in the archive.              */

/* Executable files needed by ssh. */
SSHexeFiles:
File.1  = '\ssh.exe'
File.2  = '\scp.exe'
File.3  = '\sftp.exe'
File.0  = 3
return 1

/* Executable files needed by sshd. */
SSHDexeFiles:
File.1  = '\sftp-server.exe'
File.2  = '\sshd.exe'
File.3  = '\sshd.ico'
File.4  = '\sh.exe'
File.5  = '\tnpipe.exe'
File.6  = '\viostart.exe'
File.7  = '\vioterm.exe'
File.8  = '\vioroute.exe'
File.9  = '\user.exe'
File.0  = 9
return 1

/* Executable files needed by both ssh and sshd. */
SSH_SSHDexeFiles:
File.1  = '\ssh-add.exe'
File.2  = '\ssh-agent.exe'
File.3  = '\ssh-keysign.exe'
File.4  = '\ssh-keygen.exe'
File.5  = '\ssh-keyscan.exe'
File.6  = '\ssh-rand-helper.exe'
File.0  = 6
return 1

/* DLL files needed by sshd. */
SSHDdllFiles:
File.1  = '\vioroute.dll'
File.0  = 1
return 1

/* Configuration files needed by ssh. */
SSHconfigFiles:
File.1  = '\ETC\ssh\ssh_config'
File.2  = '\rc'
File.0  = 2
return 1

/* Configuration files needed by sshd. */
SSHDconfigFiles:
File.1  = '\ETC\ssh\sshd_config'
File.2  = '\ETC\ssh\ssh_prng_cmds'
File.3  = '\ETC\ssh\ssh_term'
File.4  = '\ETC\ssh\ssh_term.bsd'
File.5  = '\ETC\ssh\ssh_term.linux'
File.6  = '\ETC\ssh\ssh_term.os2'
File.7  = '\ETC\ssh\ssh_term.sun'
File.8  = '\ETC\ssh\ssh_term.vt100'
File.9  = '\ETC\ssh\ssh_term.vt220'
File.10 = '\ETC\tnpipe_config'
File.11 = '\ETC\term.cfg'
File.12 = '\ETC\ssh\sshrc'
File.0  = 12
return 1

/* Optional files.  The user is asked about each, individual file. */
OptionalConfigFiles:
File.1  = '\etc\ssh\sshd_config.doug'
File.2  = '\ETC\ssh\SSH_BANNER.TXT'
File.3  = '\ETC\syslog.cnf'
File.0  = 3
return 1

/* Example files */
ExampleFiles:
File.0  = 0
return 1
